<?php

/* Definición del modelo Colección ==> equivale a una Colección/Exposición de 1 usuario */

namespace App;

use Illuminate\Database\Eloquent\Model;
use Carbon\Carbon;

class Exposicion extends Model
{
  // especificamos la tabla en DB
  protected $table = 'exposiciones';
  
  // especificamos los campos que podemos rellenar mediante asignación masiva
  protected $fillable = [
    'Titulo','Autor','FechaDesde','FechaHasta','Ubicacion',
    'Horario_general','URL','CuerpoWeb','Extracto','Tipo',
    'Descripcion','esPublica','user_id'
  ];
  
  // especificamos los campos que irán ocultos en los requests http
  protected $hidden = [
    'expo_token'
  ];
  
  // especificamos los campos del modelo de tipo fecha
  protected $dates = ['FechaDesde','FechaHasta'];
  
  //////////////
  // Relaciones
  //////////////
  
  // una colección pertenece a 1 organizador (usuario organizador)
  public function organizador()
  {
    return $this->belongsTo(User::class,'user_id');
  }
  
  // una colección puede tener muchas obras
  public function obras(){
    return $this->hasMany(Obra::class,'exposicion_id');
  }
  
  // Métodos
  
  // fechaDesde() y fechaHasta() nos permiten definir en el modelo el formato cómo queremos obtener
  //   las fechas de la DB, en un único lugar.
  public function fechaDesde()
  {
    return $this->FechaDesde->format('j \d\e n \d\e Y');
  }
  
  public function fechaHasta()
  {
    return $this->FechaHasta->format('j \d\e n \d\e Y');
  }
  
  // A través de la colección, damos acceso al listado de obras públicas de la colección.
  public function obras_publicas(){
    return $this
    ->obras
    ->where('esPublica',true);
  }
  
  // Generamos la URL de acceso público a la ficha de la colección.
  public function ruta_ficha_publica()
  {
    return "/expo/".$this->expo_token;
  }
  
}
