<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Exposicion;
use Carbon\Carbon;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;

class RegisterController extends Controller
{
  /*
  |--------------------------------------------------------------------------
  | Register Controller
  |--------------------------------------------------------------------------
  |
  | This controller handles the registration of new users as well as their
  | validation and creation. By default this controller uses a trait to
  | provide this functionality without requiring any additional code.
  |
  */
  
  use RegistersUsers;
  
  /**
  * Where to redirect users after registration.
  *
  * @var string
  */
  protected $redirectTo = '/home';
  
  /**
  * Create a new controller instance.
  *
  * @return void
  */
  public function __construct()
  {
    $this->middleware('guest');
  }
  
  /**
  * Get a validator for an incoming registration request.
  *
  * @param  array  $data
  * @return \Illuminate\Contracts\Validation\Validator
  */
  protected function validator(array $data)
  {
    return Validator::make($data, [
      'name' => 'required|string|max:255',
      'email' => 'required|string|email|max:255|unique:users',
      'password' => 'required|string|min:6|confirmed',
      ]);
    }
    
    /**
    * Creación de un nuevo usuario después de un registro válido
    * Se modifica la función por defecto para:
    *    1 - Pasamos el password en texto plano --> el mutador del modelo User encriptará la contraseña
    *    2 - Creamos la colección por defecto del usuario
    */
    protected function create(array $data)
    {
      $usuario = User::create([
        'name' => $data['name'],
        'email' => $data['email'],
        // 'password' => Hash::make($data['password']),
        'password' => $data['password'],
        ]);
        
        // creamos la colección base del usuario
        $exposicion = new Exposicion;
        $exposicion->user_id =  $usuario->id;
        $exposicion->Titulo = 'Base';
        $fechaDesde1 = Carbon::now()->addDays(1);
        $exposicion->FechaDesde = $fechaDesde1;
        $exposicion->FechaHasta = $fechaDesde1->addMonth();
        $exposicion->CuerpoWeb = '';
        $exposicion->Extracto = '';
        $exposicion->Tipo = '';
        $exposicion->Descripcion = '';
        $exposicion->expo_token = str_random(6);
        $exposicion->created_at = Carbon::now();
        $exposicion->save();
        
        return $usuario;
      }
    }
    