<?php

// Este es el controlador encargado de poner/quitar etiquetas (fav, like...) a cada obra

namespace App\Http\Controllers;

use App\User;
use App\Rol;
use App\Obra;
use App\AccionSocial;

use Illuminate\Http\Request;

class EtiquetaController extends Controller
{
  
  // toggle_etiqueta() aplicará la etiqueta a $obra, si no la tiene, o la quitará, si ya la tenía previamente.
  // La etiqueta aplicada se obtiene del request y el usuario que la aplica/quita se obtiene de la sesión.
  public function toggle_etiqueta(int $obra)
  {
    // Encontramos la obra o lanzamos un error
    $obraUser = Obra::findOrFail($obra);
    
    // ¿¿La etiqueta está aplicada por el usuario a la obra?
    $etiqueta_id  = request()->get('etiqueta_id');
    $user_id = auth()->user()->id;
    $tieneEtiqueta = auth()->user()->ha_etiquetado($obraUser, $etiqueta_id);
    
    if (! $tieneEtiqueta)
    {
      // No está aplicada ---> aplicamos etiqueta
      $accion = new AccionSocial;
      $accion->obra_id      = $obra;
      $accion->etiqueta_id  = $etiqueta_id;
      $accion->user_id      = $user_id;
      $accion->save();
      $mensaje = 'on_'.$etiqueta_id;
      $literal = ($etiqueta_id == 1) ? 'Añadida a tus favoritos' : 'Te gusta. ¡Bien!';
    }else{
      // Está aplicada ---> quitamos etiqueta
      $accion = AccionSocial::where('user_id',$user_id)
      ->where('obra_id',$obra)
      ->where('etiqueta_id',$etiqueta_id)
      ->delete();
      $mensaje = 'off_'.$etiqueta_id;
      $literal = ($etiqueta_id == 1) ? 'Eliminada de tus favoritos' : 'Ya no te gusta.';
    }

    // actualizamos el total de etiquetas aplicadas a la obra
    $totalEtiquetas = $obraUser->num_acciones_sociales($etiqueta_id);

    // devolvemos un string con toda la información: [on|off_etiquetaId_totalEtiquetas_MensajeFeedbackUsuario]
    // el string se troceará en un array de 4 posiciones. Lo trocearemos con el caracter '_'
    return $mensaje.'_'.$totalEtiquetas.'_'.$literal;    
    
  }
}
