<?php

// Controlador que alberga como servimos diversas páginas, en general estáticas, de la aplicación, por ejemplo, la parte pública de la web.
// También, el acceso a las fichas públicas de obra y colección y el envío de mensajes del formulario de contacto.
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Obra;
use App\Exposicion;
use Carbon\Carbon;
use Mail;
use App\Mail\FormularioDeContacto;

class PagesController extends Controller
{
  /*
  * Servimos las páginas públicas estáticas
  */
  public function home(){
    return view('static.home');
  }
  
  public function porque_enlazart(){
    return view('static.por-que-enlazart');
  }
  
  public function planes(){
    return view('static.planes');
  }

  public function privacidad(){
    return view('static.privacidad');
  }
  
  public function conocenos(){
    return view('static.conocenos');
  }
  
  public function contacta(){
    return view('static.contacta');
  }
  
  public function como_funciona(){
    return view('static.como-funciona');
  }
 
  public function tour(){
    return view('static.tour');
  }
  
  /*
  * Envío de mensajes a través del formulario de contacto.
  */
  public function enviar_mensaje_contacto(Request $request)
  {
    // Validamos el formulario de envío de mensajes
    $this->validate($request, [
      'name'    => 'required', // requerido
      'email'   => 'required|email', // requerido y dirección de email
      'subject'   => 'required', // requerido
      'Mensaje' => 'required' // requerido
      ]
    );
    
    // Usamos el facade Mail para enviar 2 correos electrónicos:
    //    - el primero a la plataforma (admin@enlaz.art)
    //    - el segundo, copia para el remitente del mensaje
    // El mensaje enviado usa la clase Mail (ahí definimos la plantilla) ubicada en app/Mail/FormularioDeContacto.php
    Mail::to('admin@enlaz.art','Equipo enlaz.art')->send(new FormularioDeContacto($request));
    Mail::to($request->email,$request->name)->send(new FormularioDeContacto($request));
    
    // Enviados los mensajes, redirigimos y damos feedback al usuario.
    return redirect()
    ->route('contacta')
    ->with(['tipo' => 'success', 'info' => 'Su mensaje ha sido enviado. ¡Gracias por contactar con nosotros! Le responderemos a la mayor brevedad']);
  }
  
  /*
  * Control de acceso a la ficha pública de la obra. Localizamos la obra por $obra_token (cadena única y aleatoria)
  */
  public function ficha_publica($obra_token){
    // Localizamos la obra o lanzamos error.
    $obra = Obra::where('obra_token',$obra_token)->firstOrFail();
    // Comprobamos que que la ficha pública está visible.
    if (!$obra->esPublica){
      // Si la obra no es pública, lanzamos un error 500 personalizado.
      // La visa del error personalizado está en resources/views/errors/500.blade.php
      abort(500, 'La obra no se encuentra publicada.');
    }
    // Obra pública, servimos la ficha pública.
    return view('obras.ficha-publica',compact('obra'));
    
  }
  
  /*
  * Control de acceso a la ficha pública de la colección. Localizamos la colección por $expo_token (cadena única y aleatoria)
  */
  public function ficha_publica_coleccion($expo_token){
    // Localizamos la colección o lanzamos error.
    $exposicion = Exposicion::where('expo_token',$expo_token)->firstOrFail();
    
    // Como existe la colección, verificamos que sea pública y que esté en el rango de fechas de acceso público.
    // Si incumple alguna de estas condiciones, lanzamos un error 500 personalizado.
    if (!$exposicion->esPublica){
      abort(500, 'La colección no se encuentra publicada.');
    }
    // comprobar las fechas de publicación de la exposición
    $publicacionFutura =  Exposicion::where('expo_token', $expo_token)
    ->whereDate('FechaDesde', '<=', Carbon::now())
    ->first();
    if (!$publicacionFutura){
      abort(500, 'La colección será visible desde el ' .$exposicion->fechaDesde() . '.');
    }
    $publicacionCaducada =  Exposicion::where('expo_token', $expo_token)
    ->whereDate('FechaHasta', '>=', Carbon::now())
    ->first();
    if (!$publicacionCaducada){
      abort(500, 'La colección ha caducado.');
    }
    
    // Si estamos aquí, la colección existe, es pública y está fechas de acceso permitido. --> La mostramos.
    return view('colecciones.ficha-publica',compact('exposicion'));
  }
  
}
