<?php

namespace App\Http\Requests;

use App\User;
use Carbon\Carbon;
use Illuminate\Foundation\Http\FormRequest;

class ActualizarColeccionRequest extends FormRequest
{
  /**
  * Esta función se puede usar para comprobar si el usuario tiene autorización o implementar alguna comprobación adicional.
  * En nuestro caso, simplemente la puenteamos devolviendo true.
  */
  public function authorize()
  {
    return true;
  }
  
  /**
  * Reglas de validación para la actualización de la colección
  */
  public function rules()
  {
    
    // Calculamos las fechas inicial (desde el formulario) y final (la inicial más los días permitidos por el plan del usuario) 
    $fecha_inicial = Carbon::parse($this->get('FechaDesde'));
    $fecha_tope    = $fecha_inicial
    ->addDays(auth()->user()->dias_plan())
    ->toDateString();
    
    return [
      'Titulo' => 'required', // requerido
      'Autor' => 'nullable|string', // no requerido, de formato string
      'FechaDesde' => 'nullable|date', // no requerido, formato fecha
      'FechaHasta' => 'nullable|date|before:' . $fecha_tope . '|after:FechaDesde', // no requerido, formato fecha, la fecha anterior a $fecha_tope y posterior a FechaDesde
      'Ubicacion' => 'nullable|string', // no requerido, de formato string
      'Horario_general' => 'nullable|string', // no requerido, de formato string
      'URL' => 'nullable|URL', // no requerido, de formato URL
      'CuerpoWeb' => 'nullable|string', // no requerido, de formato string
      'Extracto' => 'nullable|string', // no requerido, de formato string
      'Tipo' => 'nullable|string', // no requerido, de formato string
      'Descripcion' => 'nullable|string', // no requerido, de formato string
    ];
  }
}
