<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

class ActualizarUsuarioRequest extends FormRequest
{
  /**
  * Esta función se puede usar para comprobar si el usuario tiene autorización o implementar alguna comprobación adicional.
  * En nuestro caso, simplemente la puenteamos devolviendo true.
  */
  public function authorize()
  {
    return true;
  }
  
  /**
  * Reglas de validación
  */
  public function rules()
  {
    // Estas reglas se aplican siempre
    $rules = [
      'name' => 'required', // requerido
      'email' => [
        'required', // requerido
        'email', // formato email
        'unique:users,email,'.$this->route('usuario')->id // el email debe ser único en la tabla de usuarios. Se configura la regla para que tenga en cuenta que el usuario que estamos actualizando ya tiene ese email registrado.
      ],
      'rol_id' => 'required', // requerido
    ];
    
    // Estas reglas sólo se aplican si se está actualizando el password
    if ($this->filled('password')){
      $rules['password'] = ['confirmed','min:6']; // password tiene que estar confirmado (2 campos password coincidentes) y mínimo de 6 caracteres.
    }
    
    return $rules;
  }
}
