<?php

/*
 * Personalización del mensaje de email de restablecimiento de contraseña
 */

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Notifications\Notification;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;

class ResetPasswordNotification extends Notification
{
  /**
  * The password reset token.
  *
  * @var string
  */
  public $token;
  
  /**
  * The callback that should be used to build the mail message.
  *
  * @var \Closure|null
  */
  public static $toMailCallback;
  
  /**
  * Create a notification instance.
  *
  * @param  string  $token
  * @return void
  */
  public function __construct($token)
  {
    $this->token = $token;
  }
  
  /**
  * Get the notification's channels.
  *
  * @param  mixed  $notifiable
  * @return array|string
  */
  public function via($notifiable)
  {
    return ['mail'];
  }
  
  /**
  * Build the mail representation of the notification.
  *
  * @param  mixed  $notifiable
  * @return \Illuminate\Notifications\Messages\MailMessage
  */
  public function toMail($notifiable)
  {
    if (static::$toMailCallback) {
      return call_user_func(static::$toMailCallback, $notifiable, $this->token);
    }
    
    return (new MailMessage)
    ->subject('Solicitud de restablecimiento de contraseña')
    ->greeting('Hola '.$notifiable->name)
    ->line('Recibe este correo porque se solicitó un restablecimiento de contraseña para esta cuenta.')
    ->action('Restablecer contraseña', url(config('app.url').route('password.reset', $this->token, false)))
    ->line('Si no solicitó un restablecimiento de contraseña, ignore este correo.')
    ->salutation('¡Saludos!');
  }
  
  /**
  * Set a callback that should be used when building the notification mail message.
  *
  * @param  \Closure  $callback
  * @return void
  */
  public static function toMailUsing($callback)
  {
    static::$toMailCallback = $callback;
  }
}

