<?php

/* Definición del modelo Obra ==> equivale a una Obra de 1 usuario */

namespace App;

use Illuminate\Database\Eloquent\Model;

class Obra extends Model
{
  // especificamos la tabla en DB
  protected $table = 'obras';
  
  // especificamos los campos que podemos rellenar mediante asignación masiva
  protected $fillable = [
    'Titulo','Autor','URL','Fecha','CuerpoWeb',
    'Tecnica','Medidas','Planta','Ubicacion','Foto',
    'Thumb','user_id','exposicion_id','Descripcion','obra_token'
    
  ];
  
  // especificamos los campos que irán ocultos en los requests http
  protected $hidden = [
    'obra_token'
  ];
  
  // Relaciones
  
  // Una obra puede tener muchas AccionesSociales()
  public function acciones_sociales()
  {
    return $this->hasMany(AccionSocial::class);
  }
  
  // Una obra pertenece a 1 colección
  public function exposicion()
  {
    return $this->belongsTo(Exposicion::class,'exposicion_id');
  }
  
  // Una obra pertenece a 1 usuario organizador  
  public function organizador()
  {
    return $this->belongsTo(User::class,'user_id');
  }
  
  // Métodos
  
  // Obtener el número de etiquetas aplicadas a 1 obra
  public function num_acciones_sociales(int $etiqueta)
  {
    return $this
    ->acciones_sociales
    ->where('etiqueta_id',$etiqueta)
    ->count();
  }
  
  // Generamos la URL de acceso público a la ficha de la obra.
  public function ruta_ficha_publica()
  {
    return "/id/".$this->obra_token;
  }
  
}
