<?php

/*
*  Definimos la política de acceso (policy) para Colecciones.
*  Hay que definir cada función con el mismo nombre (exacto) que luego queramos comprobar...
*/

namespace App\Policies;

use App\User;
use App\Exposicion;
use Illuminate\Auth\Access\HandlesAuthorization;

class ExposicionesPolicy
{
  use HandlesAuthorization;
  
  /*
   * La función before() nos permite obviar el resto de la política de acceso en determinados casos.
   * En nuestro caso, si el usuario es administrador (tiene el rol de administrador), tendrá autorización directamente.
   */
  public function before($user, $ability)
  {
    if ($user->esAdministrador())
    {
      return true;
    }
  }
  
  /*
   * En cada función (edit(), show()...) validamos que el usuario autenticado sea el mismo que el que tiene asignada la colección sobre la que se quiere actuar.
   */
  public function edit(User $user, Exposicion $exposicion)
  {
    return $user->id === $exposicion->organizador->id;
  }
  
  public function show(User $user, Exposicion $exposicion)
  {
    return $user->id === $exposicion->organizador->id;
  }
  
  public function update(User $user, Exposicion $exposicion)
  {
    return $user->id === $exposicion->organizador->id;
  }
  
  public function publicar_coleccion(User $user, Exposicion $exposicion)
  {
    return $user->id === $exposicion->organizador->id;
  }
  
}
