<?php

/*
*  Definimos la política de acceso (policy) para Usuarios.
*  Hay que definir cada función con el mismo nombre (exacto) que luego queramos comprobar...
*/

namespace App\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;

class UsuarioPolicy
{
  use HandlesAuthorization;

  /*
  * La función before() nos permite obviar el resto de la política de acceso en determinados casos.
  * En nuestro caso, si el usuario es administrador (tiene el rol de administrador), tendrá autorización directamente.
  */
  public function before($user, $ability)
  {
    if ($user->esAdministrador())
    {
      return true;
    }
  }
  
  /*
  * En cada función (edit(), show()...) validamos que el usuario autenticado sea el mismo que el usuario sobre el que se quiere actuar.
  * $authUser --> usuario autenticado
  * $user ------> usuario sobre el que se pretende ejecutar el método
  */
  public function edit(User $authUser, User $user)
  {
    return $authUser->id === $user->id;
  }
  
  public function update(User $authUser, User $user)
  {
    return $authUser->id === $user->id;
  }
  
  public function show(User $authUser, User $user)
  {
    return $authUser->id === $user->id;
  }
  
  public function destroy(User $authUser, User $user)
  {
    return $authUser->id === $user->id;
  }
  
  
}
