<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateRolsTable extends Migration
{
  /**
  * Crear la tabla 'roles'
  */
  public function up()
  {
    Schema::create('roles', function (Blueprint $table) {
      $table->increments('id'); // índice id
      $table->string('clave')->unique(); // campo string 'clave', único
      $table->string('nombre'); // campo string 'nombre'
      $table->text('descripcion')->nullable(); // campo texto 'descripcion', puede ser nulo
      $table->integer('coste_mensual'); // campo entero
      $table->integer('max_colecciones'); // entero
      $table->integer('max_obras'); // entero
      $table->integer('max_dias_duracion'); // entero
      $table->text('para_quien'); // texto
      $table->string('avatar')->nullable(); // cadena, puede ser nulo
      $table->timestamps(); // campos de fecha 'updated_at', 'created_at'
    });
    
    // Al crear la tabla, insertamos los roles directamente en DB --> En la versión 1.0 de enlaz.art, no se modifican los roles, ni se personalizan por usuario.
    
    // Rol de Administrador
    DB::table('roles')->insert(array(
      'id'=>'1',
      'clave'=>'admin',
      'nombre'=>'Administrador',
      'coste_mensual'=> 0,
      'max_colecciones'=>1,
      'max_obras'=>1000,
      'max_dias_duracion'=>10000,
      'para_quien'=>'Equipo enlaz.art',
      'avatar'=>'/images/avatars/avatar_administrador.png'
    ));
    
    // Plan Esencial
    DB::table('roles')->insert(array(
      'id'=>'2',
      'clave'=>'esencial',
      'nombre'=>'Plan Esencial',
      'coste_mensual'=> 0,
      'max_colecciones'=>1,
      'max_obras'=>25,
      'max_dias_duracion'=>30,
      'para_quien'=>'Acceso libre',
      'avatar'=>'/images/avatars/avatar_esencial.png'
    ));
    
    // Plan Estandar
    DB::table('roles')->insert(array(
      'id'=>'3',
      'clave'=>'estandar', 
      'nombre'=>'Plan Estándar',
      'coste_mensual'=> 0,
      'max_colecciones'=>1,
      'max_obras'=>50,
      'max_dias_duracion'=>60,
      'para_quien'=>'Cuentas verificadas: organizaciones sin ánimo de lucro',
      'avatar'=>'/images/avatars/avatar_estandar.png'
    ));
  }
  
  /**
  * Eliminar la tabla 'roles'
  */
  public function down()
  {
    Schema::dropIfExists('roles');
  }
}
