<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateExposicionesTable extends Migration
{
  /**
  * Crear la tabla 'exposiciones'
  */
  public function up()
  {
    Schema::create('exposiciones', function (Blueprint $table) {
      $table->increments('id'); // índice 'id'
      $table->unsignedInteger('user_id'); // entero
      // Definimos la clave foránea, que relaciona la colección con el usuario al que pertenece.
      //  También, el comportamiento en borrado y actualización del usuario (onDelete, onUpdate).
      $table->foreign('user_id')
      ->references('id')->on('users')
      ->onDelete('cascade')
      ->onUpdate('cascade');
      
      $table->string('Titulo')->default('Permanente'); // cadena, por defecto "Permanente"
      $table->string('Autor')->nullable(); // cadena, puede ser nulo
      $table->date('FechaDesde')->nullable(); // fecha, puede ser nulo
      $table->date('FechaHasta')->nullable(); // fecha, puede ser nulo
      $table->string('Ubicacion')->nullable(); // cadena, puede ser nulo
      $table->text('Horario_general')->nullable(); // texto, puede ser nulo
      $table->string('URL')->nullable(); // cadena, puede ser nulo
      
      $table->text('CuerpoWeb')->nullable(); // texto, puede ser nulo
      $table->text('Extracto')->nullable(); // texto, puede ser nulo
      $table->text('Tipo')->nullable(); // texto, puede ser nulo
      
      // información de gestión de la obra
      $table->string('Descripcion')->nullable(); // cadena, puede ser nulo
      $table->boolean('esPublica')->default(0); // boolean, por defecto 'false', esto es, la colección no es visible
      $table->string('expo_token')->unique(); // cadena, única
      $table->timestamps(); // campos de fecha 'updated_at', 'created_at'
    });
  }
  
  /**
  * Eliminar la tabla 'exposiciones'
  */
  public function down()
  {
    Schema::dropIfExists('exposiciones');
  }
}
