<?php

use Illuminate\Support\Facades\Schema;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateObrasTable extends Migration
{
   /**
  * Crear la tabla 'obras'
  */
  public function up()
  {
    Schema::create('obras', function (Blueprint $table) {
      // información de la obra
      $table->increments('id'); // índice 'id'
      $table->string('Titulo'); // cadena
      $table->string('Autor'); // cadena
      $table->string('URL')->nullable(); // cadena, puede ser nulo
      $table->string('Fecha'); // cadena, la fecha la registraos como literal
      $table->text('CuerpoWeb')->nullable(); // texto, puede ser nulo
      $table->string('Tecnica')->nullable(); // cadena, puede ser nulo
      $table->string('Medidas')->nullable(); // cadena, puede ser nulo
      $table->string('Planta')->nullable(); // cadena, puede ser nulo
      $table->string('Ubicacion')->nullable(); // cadena, puede ser nulo
      $table->string('Foto')->nullable(); // cadena, puede ser nulo
      $table->string('Thumb')->nullable(); // cadena, puede ser nulo
      
      $table->unsignedInteger('user_id'); // entero sin signo
      $table->unsignedInteger('exposicion_id'); // entero sin signo
      // claves foráneas y sus comportamientos en borrado y actualización (onDelete, onUpdate)
      $table->foreign('user_id')
      ->references('id')->on('users')
      ->onDelete('cascade')
      ->onUpdate('cascade');
      $table->foreign('exposicion_id')
      ->references('id')->on('exposiciones')
      ->onDelete('cascade')
      ->onUpdate('cascade');
      
      // información de gestión de la obra
      $table->string('Descripcion')->nullable();  // cadena, puede ser nulo
      $table->boolean('esPublica')->default(0); // booleano, por defecto 0=no visible
      $table->string('obra_token')->unique();  // cadena, valor único en la tabla
      $table->string('codigoQR')->nullable();  // cadena, puede ser nulo
      $table->boolean('tieneEtiqueta')->default(0); // booleano, por defecto 0=sin etiqueta
      $table->string('imagenEtiqueta')->nullable(); // cadena, puede ser nulo
      
      $table->timestamps(); // campos de fecha 'updated_at', 'created_at'
    });
  }
  
  /**
  * Eliminar la tabla 'obras'
  */
  public function down()
  {
    Schema::dropIfExists('obras');
  }
}
