{{-- Vista edición de colección. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@section('contenido')
<div class="container mt-4">
  <div class="row mb-3">
    <div class="col">
      <h1>Editar colección "{{ $exposicion->Titulo }}"</h1>
    </div>
  </div>
  
  @if (session()->has('info'))
  @component('components.info_box', session('tipo'))
  {{ session('info') }}
  @endcomponent
  @endif
  
  <form method="post" action="{{ route('colecciones.update',$exposicion->id) }}">
    
    {{-- Simulamos el método PUT (la petición http es de tipo POST) --}}
    {!! method_field('PUT') !!}
    {!! csrf_field() !!}
    
    <div class="row">
      <div class="col-sm-12 col-md-6 col-lg-4">
        
        <fieldset class="form-group">
          <label for="Titulo">Título <small class="text-primary ml-1">* Obligatorio</small></label>
          <input type="text" class="form-control" name="Titulo" id="Titulo" value="{{ (old('Titulo')) ? (old('Titulo')) : ($exposicion->Titulo)  }}" placeholder="Título de la colección" required>
          {!! $errors->first('Titulo','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Autor">Autor</label>
          <input type="text" class="form-control" name="Autor"  id="Autor"  value="{{ (old('Autor')) ? (old('Autor')) : ($exposicion->Autor) }}"  placeholder="Autor de la colección">
          {!! $errors->first('Autor','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Descripcion">Descripción <small class="text-muted">interna</small></label>
          <textarea class="form-control" name="Descripcion"  id="Descripcion" rows="2">{{ (old('Descripcion')) ? (old('Descripcion')) : ($exposicion->Descripcion) }}</textarea>
          <small class="text-muted">Descripción no visible en la ficha pública de la colección.</small>
          {!! $errors->first('Descripcion','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <div class="row">
          <div class="col-6">
            <fieldset class="form-group">
              <label for="FechaDesde">Fecha de comienzo</label>
              <input type="date" class="form-control"
              name="FechaDesde" id="FechaDesde"  
              {{-- Formateamos el valor de la fecha desde DB al formato requerido para el control html --}}
              value="{{ (old('FechaDesde')) ? (old('FechaDesde')) : ($exposicion->FechaDesde->format('Y-m-d')) }}"  
              placeholder="Fecha de comienzo de la muestra"
              {{-- Si la exposición es pública, la fecha no puede editarse --}}
              {{ ($exposicion->esPublica) ? 'disabled' : '' }}
              >
              {!! $errors->first('FechaDesde','<p class=text-danger>:message</p>') !!}
            </fieldset>
          </div>
          <div class="col-6">
            <fieldset class="form-group">
              <label for="FechaHasta">Fecha de cierre</label>
              <input type="date" class="form-control" 
              name="FechaHasta" id="FechaHasta"
              {{-- Formateamos el valor de la fecha desde DB al formato requerido para el control html --}}
              value="{{ (old('FechaHasta')) ? (old('FechaHasta')) : ($exposicion->FechaHasta->format('Y-m-d')) }}"  
              placeholder="Fecha de cierre de la muestra"
              {{-- Si la exposición es pública, la fecha no puede editarse --}}
              {{ ($exposicion->esPublica) ? 'disabled' : '' }}
              >
              {!! $errors->first('FechaHasta','<p class=text-danger>:message</p>') !!}
            </fieldset>
            
          </div>
        </div>
      </div>
      
      <div class="col-md-12 col-lg-4">
        <fieldset class="form-group">
          <label for="Extracto">Extracto <small class="text-muted">o entradilla</small></label>
          <input type="text" class="form-control" name="Extracto"  id="Extracto"  value="{{ (old('Extracto')) ? (old('Extracto')) : ($exposicion->Extracto) }}"  placeholder="Entradilla o descripción corta de la muestra">
          {!! $errors->first('Extracto','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="CuerpoWeb">Descripción web</label>
          <textarea class="form-control" name="CuerpoWeb"  id="enlazartEditor" rows="8">{!! (old('CuerpoWeb')) ? (old('CuerpoWeb')) : ($exposicion->CuerpoWeb) !!}</textarea>
          <small class="text-muted">Este texto aparecerá en la ficha de la muestra en la web. Acepta HTML.</small>
          {!! $errors->first('CuerpoWeb','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
      </div>
      
      <div class="col-sm-12 col-md-6 col-lg-4">
        <fieldset class="form-group">
          <label for="Ubicacion">Ubicación</label>
          <input type="text" class="form-control" name="Ubicacion"  id="Ubicacion"  value="{{ (old('Ubicacion')) ? (old('Ubicacion')) : ($exposicion->Ubicacion) }}"  placeholder="Ubicación de la muestra">
          {!! $errors->first('Ubicacion','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Horario_general">Horario general</label>
          <input type="text" class="form-control" name="Horario_general"  id="Horario_general"  value="{{ (old('Horario_general')) ? (old('Horario_general')) : ($exposicion->Horario_general) }}"  placeholder="Horario general de la muestra">
          {!! $errors->first('Horario_general','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Tipo">Tipo</label>
          <input type="text" class="form-control" name="Tipo"  id="Tipo"  value="{{ (old('Tipo')) ? (old('Tipo')) : ($exposicion->Tipo) }}"  placeholder="Fotografía, pintura, escultura...">
          {!! $errors->first('Tipo','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="URL">Página web con más información</label>
          <input type="text" class="form-control" name="URL"  id="URL"  value="{{ (old('URL')) ? (old('URL')) : ($exposicion->URL) }}"  placeholder="http://pagina-con-mas-informacion">
          {!! $errors->first('URL','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
      </div>
    </div>
    
    
    
    <div class="row mb-sm-4">
      <div class="col"><button type="submit" class="btn btn-primary btn-lg mt-5">Editar colección</button></div>
    </div>
  </form>
  
</div>
@endsection

@push('scripts')
<script src="//cdn.ckeditor.com/4.8.0/basic/ckeditor.js"></script>
<script>
  CKEDITOR.replace( 'enlazartEditor' );
</script>
@endpush
