{{-- Vista listado de colecciones. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@section('contenido')
  <div class="container mt-4">

    <div class="row mb-5">
      <div class="col">
        <h1>Mis colecciones</h1>
        <small class="text-muted">{{ auth()->user()->colecciones_publicas() }} públicas de {{ auth()->user()->colecciones_disponibles() }} disponibles</small>
      </div>
    </div>

    @if (session()->has('info'))
      @component('components.info_box', ['tipo'=> session('tipo')])
        {{ session('info') }}
      @endcomponent
    @endif


    <table class="table table-hover table-bordered table-sm">
      <thead>
        <tr>
          <th>Id</th>
          <th>Estado</th>
          <th>Título</th>
          <th>Autor</th>
          <th>Información</th>
          <th>Obras</th>
          <th>Acciones</th>
        </tr>
      </thead>
      <tbody>
          @foreach ($exposiciones as $expo)
            <tr>
              <td class="text-center">{{ $expo->id }}</td>
              <td>

                @if ($expo->esPublica)
                  <a href="{{ $expo->ruta_ficha_publica() }}" class="badge badge-success" target="_blank">Pública</a>
                @else
                  <a href="{{ $expo->ruta_ficha_publica() }}" class="badge badge-secondary" target="_blank">No visible</a>
                @endif

              </td>
              <td>
                <a href="{{ route('colecciones.show',$expo->id) }}">
                  {{ $expo->Titulo }}
                </a>
              </td>
              <td>{{ $expo->Autor }}</td>
              <td><small>Del {{ $expo->fechaDesde()  }} al {{ $expo->fechaHasta() }}<br />{{ $expo->Ubicacion }}</small></td>
              <td>{{ $expo->obras->count() }}</td>
              <td>
                <a href="{{ route('colecciones.edit',$expo->id) }}" class="btn btn-outline-primary btn-sm" title="Editar">
                  <span class="oi oi-pencil"></span>
                </a>
                
                {{-- Si la expo no está publicada, damos la opción. Es una acción irreversible, por lo que ponemos una confirmación en ventana modal --}}
                @if (! $expo->esPublica)
                <button type="button" class="btn btn-outline-primary btn-sm d-inline" data-toggle="modal" data-target="#Confirmacion{{ $expo->id }}" title="Publicar colección">
                  <span class="oi oi-circle-check"></span>
                </button>
                @endif
                
                <div class="modal fade" id="Confirmacion{{ $expo->id }}" tabindex="-1" role="dialog" aria-labelledby="ConfirmacionTitulo" aria-hidden="true">
                    <div class="modal-dialog" role="document">
                      <div class="modal-content">
                        <div class="modal-header">
                          <h5 class="modal-title" id="ConfirmacionTitulo">Confirmar publicación de colección</h5>
                          <button type="button" class="close" data-dismiss="modal" aria-label="Cerrar">
                            <span aria-hidden="true">&times;</span>
                          </button>
                        </div>
                        <div class="modal-body">
                          <p><strong>Atención</strong>: esta acción es irreversible.</p>
                          <p>Al publicar la colección:</p>
                          <ul>
                            <li>La ficha de la colección/exposición será <strong>visible</strong> para todo el mundo.</li>
                            <li>La ficha estará accesible únicamente <strong>durante el rango de fechas</strong> seleccionado.</li>
                            <li><strong>Podrás continuar editando</strong> la ficha de la colección, excepto las fechas.</li>
                            <li><strong>No podrás </strong> volver a ocultar la ficha de la colección/exposición.</li>
                          </ul>
                          <p><strong>¿Estás seguro de que deseas publicar la colección?</strong></p>
                        </div>
                        <div class="modal-footer">
                          <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancelar</button>
                          <form class="d-inline" method="post" action="{{ route('colecciones.publicar', $expo->id) }}">
                              {!! csrf_field() !!}
                              <button type="submit" class="btn btn-primary d-inline" title="Publicar colección">
                                Publicar colección
                              </button>
                            </form>
                        </div>
                      </div>
                    </div>
                  </div>

                
              </td>
            </tr>
          @endforeach
      </tbody>
    </table>

    @if ($exposiciones->count() == 0)
      @component('components.static_info_sin_expos')
      @endcomponent
    @endif
  </div>
@endsection

