{{-- Vista creación de nueva obra. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@push('styles')
{{-- Estilos adicionales --> estilos para el componente dropzone --}}
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.4.0/min/dropzone.min.css"> 
@endpush

@section('contenido')
<div class="container mt-4">
  
  <div class="row">
    <div class="col mt-2 mb-3">
      <h1>Alta de nueva obra</h1>
    </div>
  </div>
  
  {{-- Si hay llamada anterior, damos feedback. Si no, mostramos el formulario --}}
  @if (session()->has('info')) 
  @component('components.info_box', session('tipo')) {{ session('info') }} 
  @endcomponent
  @else
  
  <form method="post" action="{{ route('obras.store') }}">
    
    {{-- Seguridad: Campo CSRF, para evitar ataques CSS --}}
    {{ csrf_field() }}
    
    <div class="row">
      <div class="col-4">
        
        <fieldset class="form-group">
          <label for="exposicion_id">Colección
            <small class="text-primary ml-1">* Obligatorio</small>
          </label>
          {{-- Lista de colecciones del usuario para asignar la obra. --}}
          <select class="form-control" name="exposicion_id" id="exposicion_id" required>
            @foreach ($exposiciones as $id => $Titulo )
            <option value="{{$id}}" {{ $id === $id ? 'selected' : '' }}>{{$Titulo}}</option>
            @endforeach
          </select>
          {!! $errors->first('exposicion_id','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Titulo">Título
            <small class="text-primary ml-1">* Obligatorio</small>
          </label>
          <input type="text" class="form-control" name="Titulo" id="Titulo" value="{{ old('Titulo') }}" placeholder="Título de la obra"
          required>
          {!! $errors->first('Titulo','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        
        <fieldset class="form-group">
          <label for="Autor">Autor
            <small class="text-primary ml-1">* Obligatorio</small>
          </label>
          <input type="text" class="form-control" name="Autor" id="Autor" value="{{ old('Autor') }}" placeholder="Autor de la obra"
          required>
          {!! $errors->first('Autor','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Fecha">Fecha de creación
            <small class="text-primary ml-1">* Obligatorio</small>
          </label>
          <input type="text" class="form-control" name="Fecha" id="Fecha" value="{{ old('Fecha') }}" placeholder="Fecha de creación" required>
          {!! $errors->first('Fecha','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        {{-- Campo imagen de la obra. Se gestiona con Dropzone (ver sección de scripts) --}}
        <fieldset class="form-group">
          <label for="Thumb">Imagen
          </label>
          <div class="dropzone"></div>
          <p id="ThumbError" class="text-danger"></p>
          <input type="hidden" name="Thumb" id="Thumb" value="">
          <div id="FotoObra" class="row">
            <div class="col-3">
              <img id='FotoThumb' src="" class="img-fluid">
            </div>
          </div>
        </fieldset>
        
      </div>
      
      <div class="col-4">
        <fieldset class="form-group">
          <label for="Tecnica">Técnica</label>
          <input type="text" class="form-control" name="Tecnica" id="Tecnica" value="{{ old('Tecnica') }}" placeholder="Técnica de la obra"> {!! $errors->first('Tecnica','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Medidas">Medidas</label>
          <input type="text" class="form-control" name="Medidas" id="Medidas" value="{{ old('Medidas') }}" placeholder="Medidas de la obra"> {!! $errors->first('Medidas','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Planta">Planta</label>
          <input type="text" class="form-control" name="Planta" id="Planta" value="{{ old('Planta') }}" placeholder="Planta donde se ubica la obra"> {!! $errors->first('Planta','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Ubicacion">Ubicación</label>
          <input type="text" class="form-control" name="Ubicacion" id="Ubicacion" value="{{ old('Ubicacion') }}" placeholder="Ubicación de la obra"> {!! $errors->first('Ubicacion','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="URL">Página web con más información</label>
          <input type="text" class="form-control" name="URL" id="URL" value="{{ old('URL') }}" placeholder="http://pagina-con-mas-informacion"> {!! $errors->first('URL','<p class=text-danger>:message</p>') !!}
        </fieldset>
      </div>
      
      <div class="col-4">
        <fieldset class="form-group">
          <label for="CuerpoWeb">Descripción web</label>
          <textarea class="form-control" name="CuerpoWeb" id="enlazartEditor" rows="3">{{ old('CuerpoWeb') }}</textarea>
          <small class="text-muted">Este texto aparecerá en la ficha de la obra en la web. Acepta HTML.</small>
          {!! $errors->first('CuerpoWeb','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="Descripcion">Descripción</label>
          <textarea class="form-control" name="Descripcion" id="Descripcion" rows="2">{{ old('Descripcion') }}</textarea>
          <small class="text-muted">Descripción interna (no visible) de la obra.</small>
          {!! $errors->first('Descripcion','<p class=text-danger>:message</p>') !!}
        </fieldset>
      </div>
    </div>
    
    <div class="row">
      <div class="col">
        <button type="submit" class="btn btn-primary btn-lg mt-2">Dar de alta obra</button>
      </div>
    </div>
  </form>
  
  
</div>
@endif

@endsection

{{-- Scripts adicionales de la página --}}
@push('scripts')
{{-- Importamos las librerías necesarias: ckeditor y dropzone --}}
<script src="//cdn.ckeditor.com/4.8.0/basic/ckeditor.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/dropzone/5.4.0/min/dropzone.min.js"></script>

<script>
  // Inicializamos el editor enriquecido ckeditor
  CKEDITOR.replace('enlazartEditor');
  
  // inicializamos el área de subida de archivos dropzone
  var miDropzone = new Dropzone('.dropzone', {
    url: '/obra/{{ auth()->user()->id }}', // url destino
    dictDefaultMessage: 'selecciona la imagen (mínimo 600x600 px y hasta 2 Mb)', // mensaje por defecto del área del control
    addRemoveLinks: true, // que muestre enlaces para eliminar los archivos subidos
    // varias traducciones de literales
    dictRemoveFile: 'Borrar foto',
    dictCancelUpload: 'Cancelar subida',
    dictCancelUploadConfirmation: '¿Está seguro de que deseas cancelar la subida?',
    dictFileTooBig: 'El archivo es demasiado grande: @{{filesize}} Mb y el máximo es @{{maxFilesize}} Mb.',
    dictMaxFilesExceeded: 'Sólo puedes subir @{{maxFiles}} imagen',
    paramName: 'fotoObra', // el archivo subido irá en este parámetro a url
    acceptedFiles: 'image/*', // restricción del tipo de archivos admitidos
    maxFilesize: 2, // tamaño máximo permitido en Mb
    maxFiles: 1, // número máximo de archivos a subir
    headers: {
      'X-CSRF-TOKEN': '{{ csrf_token() }}' // cabecera CSRF hacia URL, por seguridad
    }
    
  });
  
  // gestión de errores -> feedback al usuario  
  miDropzone.on('error', function (file, res) {
    if (res.hasOwnProperty('errors')){
      var msg_error = res.errors.fotoObra[0];
    }else{
      var msg_error = res;
    }
    $('.dz-error-message:last > span').text(msg_error);
    $('#ThumbError').text(msg_error);
  });
  
  // cuando se borra un archivo previamente subido, hay que dar la orden al servidor para borrarlo en el almacenamiento remoto
  miDropzone.on('removedfile', function (file, res) {
    axios({
      method: 'delete', // tipo de petición
      url: '/obra/{{ auth()->user()->id }}', // url que procesará la eliminación del archivo en el servidor
      data: {
        fotoURL: $('#FotoThumb').attr("src"), // datos de la petición url que generamos --> dirección del archivo a eliminar
      },
      headers: {
        'X-CSRF-TOKEN': '{{ csrf_token() }}' // cabecera CSRF, por seguridad
      }
    }).then(res => {
      $('#FotoObra').addClass('d-none'); // cuando recibimos respuesta a la petición, damos feedback al usuario
    });
  });
  
  // cuando una subida ha culminado con éxito
  miDropzone.on('success', function (file, res) {
    $('#Thumb').val(res); // almacenamos la dirección del archivo, por si el usuario decide borrarlo...
    $('#FotoThumb').attr("src", res); // mostramos una previsualización de la subida
  });
  
  Dropzone.autoDiscover = false;
  
    </script>
    @endpush