{{-- Vista generar etiqueta. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@section('contenido')

@php
function generar_etiqueta($obra){
  
  // Marcamos que la obra tiene etiqueta en la DB y actualizamos el registro.
  $obra->tieneEtiqueta = true;
  $obra->update();
  
  // Creamos el objeto imagen de la etiqueta
  $img = Image::canvas(1323,827,'#ffffff');
  
  // Generamos e insertamos el código QR. Encadenamos la configuración de características del código.
  $qr = Image::make(base64_encode(QrCode::format('png')
  ->color(54,52,52)
  ->margin(.8)
  ->errorCorrection('Q')
  ->size(300)
  ->generate( config('app.url', 'https://enlaz.art') . $obra->ruta_ficha_publica())));
  
  // Insertamos el QR en la etiqueta
  $img->insert($qr, 'bottom-right', 114, 114);
  
  // Insertamos logo de enlaz.art en la etiqueta
  $logo = Image::make('images/static/logo-etiqueta.png');
  $img->insert($logo,'bottom-left', 118, 114);
  
  // Calculamos si el título es multilínea (intervention image no tiene opciones de word wrapping)
  // Si es necesario, ponemos el título en varias líneas.
  $pos_x      = 118;
  $pos_y      = 250;
  $max_len    = 42;
  $font_size  = 55;
  $font_height= 55;
  
  $text = $obra->Titulo;
  
  $lines = explode("\n", wordwrap($text, $max_len));
  $y     = $pos_y - ((count($lines) - 1) * $font_height);
  
  foreach ($lines as $line)
  {
    // Configuraciones para el título
    $img->text($line, $pos_x, $y, function($font) use ($font_size){
      $font->file('fonts/OpenSans-Bold.ttf');
      $font->size($font_size);
      $font->color('#000000');
      $font->align('left');
      $font->valign('top');
    });
    
    $y += $font_height;
  };
  
  // Autor de la obra
  $img->text($obra->Autor, $pos_x, 329, function($font) {
    $font->file('fonts/OpenSans-Regular.ttf');
    $font->size(40);
    $font->color('#585757');
    $font->align('left');
    $font->valign('top');
  });
  
  /*
  * Más campos informativos en la etiqueta: Fecha, Medidas, Técnica
  *
  */
  $img->text($obra->Fecha, $pos_x, 440, function($font) {
    $font->file('fonts/OpenSans-Regular.ttf');
    $font->size(32);
    $font->color('#585757');
    $font->align('left');
    $font->valign('top');
  });
  
  $img->text($obra->Medidas, $pos_x, 500, function($font) {
    $font->file('fonts/OpenSans-Regular.ttf');
    $font->size(32);
    $font->color('#585757');
    $font->align('left');
    $font->valign('top');
  });
  
  $img->text($obra->Tecnica, $pos_x, 560, function($font) {
    $font->file('fonts/OpenSans-Regular.ttf');
    $font->size(32);
    $font->color('#585757');
    $font->align('left');
    $font->valign('top');
  });
  
  // Guardamos la imagen como png
  $img->encode('png');
  
  $url =  config('app.url', 'https://enlaz.art') . $obra->ruta_ficha_publica() ;
  
  // Ponemos la etiqueta en un link para que el usuario la pueda descargar con un clic
  $tag  = "<div class='col-sm-12 col-md-6 col-lg-4 text-center'>";
    $tag .= "<a href='data:image/png;base64, ". base64_encode($img) ."' download='etiqueta-" . $obra->id . ".png' >";
      $tag .= "<img class='img-fluid img-thumbnail border border-secondary' src='data:image/png;base64, " . base64_encode($img) . "' >";
      $tag .= "</a>";
      $tag .= "<p>Su etiqueta enlaza con: <a href='" . $url ."' target='_blank'>" . $url . "</a></p>";
      $tag .= "</div>";
      
      return $tag;
    }
    @endphp
    
    <div class="container mt-5">
      <h1>Aquí están sus etiquetas</h1>
      @if ( $usuario->obras_publicadas() > 0 )
      <h5>Hemos generado las etiquetas para sus obras publicadas.</h5>
      <div class="row mt-5">
        {{-- Generamos las etiquetas para las obras publicadas del usuario --}}
        @foreach ($usuario->exposiciones()->first()->obras_publicas() as $obraUser)
        {!! generar_etiqueta($obraUser) !!}
        @endforeach
      </div>
      @else
      <div class="jumbotron text-center mt-5">
        <h1 class="display-4">¡Vaya!</h1>
        <p class="lead">Aún no tienes obras publicadas.</p>
        <p><a href="{{ route('obras.index') }}">Publica unas cuantas obras</a> y vuelve por aquí para descargar las etiquetas.</p>
        <hr class="my-4">
        <p class="lead">
          <a class="btn btn-primary btn-md" href="{{ route('obras.index') }}" role="button">Mis obras &raquo;</a>
        </p>
      </div>
      @endif 
      
      
    </div>
    @endsection
    