{{-- Vista ficha pública de la obra. Extiende la plantilla principal layouts/layout --}}
{{-- Esta vista puede mostrarse con usuario autenticado o con usuario invitado. --}}
@extends('layouts/layout')

@section('contenido')
<div class="container mt-4">
  
  <div class="row mb-3 d-none d-md-flex">
    <div class="col-12">
      <h1 class="display-5">{{ $obra->Titulo }} <small class="text-muted ml-1">de {{ $obra->Autor }}</small></h1>
      {{-- Si se accede mediante $id de obra (url es /obras/$id), el usuario está autenticado (admin o propietario de la obra) --}}
      @if (request()->is('obras*'))
      <p class="badge badge-primary mt-4">Página de previsualización</p>
      <small>Esta página es privada. La página pública está accesible en {{ env('APP_URL') . $obra->ruta_ficha_publica() }}</small>
      @endif
    </div>
  </div>
  
  <div class="row">
    @if ($obra->CuerpoWeb != null)
    <div class="col-sm-12 col-lg-4 text-center">
      @else
      <div class="col-sm-12 col-lg-6 text-center">
        @endif
        <figure class="figure">
          {{-- Si la obra no tiene imagen, mostramos una imagen genérica, definida en variables de entorno (.ENV) --}}
          <img class="img-fluid img-thumbnail" src="{{ ($obra->Thumb != null) ? $obra->Thumb : env('ENLAZART_THUMBNAIL') }}" alt="">
          <figcaption class="figure-caption">
            <p class="text-center">{{ $obra->Titulo }}, de {{ $obra->Autor }}</p>
          </figcaption>
          
          {{-- Si el usuario no ha iniciado sesión, mostramos la botonera de etiquetas deshabilitada y un link al inicio de sesión --}}
          @guest
          <div class="btn-group" role="group" aria-label="Marcar la obra como Favorito o Me gusta">
            <button type="button" class="btn btn-outline-primary btn-sm" disabled>
              <span class="oi oi-thumb-up"></span> Me gusta 
              <span class="badge badge-secondary">
                {{ $obra->num_acciones_sociales(2) }}
              </span>
            </button>
            <button type="button" class="btn btn-outline-primary btn-sm" disabled>
              <span class="oi oi-star"></span> Favorito 
              <span class="badge badge-secondary">
                {{ $obra->num_acciones_sociales(1) }}
              </span>
            </button>
          </div><br />
          <small><a href="{{ route('login') }}">Inicia sesión</a> para poder interactuar</small>
          
          @else
          {{-- Usuario autenticado: botonera habilitada --}}
          <div class="btn-group" role="group" aria-label="Marcar la obra como Favorito o Me gusta">
            <button id="2" type="button" class="etiquetar btn {{ (auth()->user()->ha_etiquetado($obra, 2)) ? 'btn-primary' : 'btn-outline-primary' }} btn-sm">
              <span class="oi oi-thumb-up"></span> Me gusta 
              <span class="badge badge-secondary">
                {{ $obra->num_acciones_sociales(2) }}
              </span>
            </button>
            <button id="1" type="button" class="etiquetar btn {{ (auth()->user()->ha_etiquetado($obra, 1)) ? 'btn-primary' : 'btn-outline-primary' }} btn-sm">
              <span class="oi oi-star"></span> Favorito 
              <span class="badge badge-secondary">
                {{ $obra->num_acciones_sociales(1) }}
              </span>
            </button>
          </div>
          <div id="feedback_etiqueta" class='text-info'>
            <small></small>
          </div>
          @endguest
          
        </figure>
      </div>
      
      @if ($obra->CuerpoWeb != null)
      <div class="col-sm-12 col-md-6 col-lg-4 mb-4">
        @else
        <div class="col-sm-12 col-lg-6">
          @endif
          <div class="card">
            <div class="card-header">Obra</div>
            <div class="card-body">
              <h5>{{ $obra->Titulo }}</h5>
              <h6>{{ $obra->Autor }}</h6>
            </div>
            @component('components.obra_card',[
            'Tecnica' => $obra->Tecnica,
            'Fecha' => $obra->Fecha,
            'Planta' => $obra->Planta,
            'Ubicacion' => $obra->Ubicacion,
            'URL' => $obra->URL,
            ])
            @endcomponent
          </div>
        </div>
        
        @if ($obra->CuerpoWeb != null)
        <div class="col-sm-12 col-md-6 col-lg-4 mb-4">
          {!! $obra->CuerpoWeb !!}
        </div>
        @endif
        
      </div>
      
    </div>
    @endsection
    
    {{-- Scripts adiconales de la página --}}
    @push('scripts')
    <script>
      
      // gestionamos el uso de la botonera de etiquetas. A cada uso, lanzamos una llamada AJAX con axios.
      $('.etiquetar').on('click', function()
      {
        axios({
          method: 'post', // método de la llamada AJAX
          url: "/etiquetar/{{ $obra->id }}", // url destino
          data: {
            etiqueta_id: $(this).attr("id"), // etiqueta que aplicamos/borramos
            obra_id: '{{ $obra->id }}', // obra afectada
          },
          headers: {
            'X-CSRF-TOKEN': '{{ csrf_token() }}' // seguridad, cabecera CSRF
          }
        }).then( res => {
          // cuando recibimos respuesta a la llamada, damos feedback
          mostrar_mensaje('#feedback_etiqueta small', res.data);
        });
      });
      
      // esta función para el feedback del usuario muestra el mensaje recibido un breve lapso de tiempo
      function mostrar_mensaje($selector,$mensaje)
      {
        // $mensaje es un string que troceamos por el '_'
        $id = $mensaje.split("_"); // on|off, etiqueta_id, total_etiquetas, literal
        
        // actualizar aspecto del botón
        $boton = $('button.etiquetar[id='+$id[1]+']');
        if ($id[0] === 'on')
        {
          $boton.addClass('btn-primary').removeClass('btn-outline-primary');
        }else{
          $boton.addClass('btn-outline-primary').removeClass('btn-primary');
        }
        $boton.find('.badge').text($id[2]);
        $($selector).append("<span class="+$id[1]+">"+$id[3]+" </span>");
        // encadenamos las transiciones de entrada y salida y, al finalizar la transición de salida, eliminamos el mensaje de feedback
        $($selector).find('span.'+$id[1]).fadeIn( 200 ).delay( 1200 ).fadeOut( 400, function(){
          $(this).remove();
        });
      }
      
    </script>
    @endpush
    