{{-- Vista listado de obras. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@section('contenido')
<div class="container mt-4">
  
  <div class="row mb-5">
    <div class="col">
      <h1>Mis obras</h1>
      <small class="text-muted">{{ auth()->user()->obras_publicadas() }} publicadas de {{ auth()->user()->obras_plan() }} disponibles</small>
    </div>
  </div>
  
  @if (session()->has('info'))
  @component('components.info_box', ['tipo'=> session('tipo')])
  {{ session('info') }}
  @endcomponent
  @endif
  
  
  <table class="table table-hover table-bordered table-sm">
    <thead>
      <tr>
        <th>Id</th>
        <th>Estado</th>
        <th>Título</th>
        <th>Autor</th>
        <th>Información</th>
        <th>Ubicación</th>
        <th>Acciones</th>
      </tr>
    </thead>
    <tbody>
      @foreach ($obras as $obra)
      <tr>
        <td class="text-center">{{ $obra->id }}</td>
        <td>
          
          @if ($obra->esPublica)
          <a href="{{ $obra->ruta_ficha_publica() }}" class="badge badge-success" target="_blank">Pública</a>
          @else
          <a href="{{ $obra->ruta_ficha_publica() }}" class="badge badge-secondary" target="_blank">No visible</a>
          @endif
          
          @if (!$obra->tieneEtiqueta)
          <br />
          <span class="badge badge-danger">Sin etiqueta</span>
          @endif
          
          @if (is_null($obra->Thumb))
          <br />
          <span class="badge badge-info">Sin imagen</span>
          @endif  
        </td>
        <td>
          <a href="{{ route('obras.show',$obra->id) }}">
            {{ $obra->Titulo }}
          </a>
        </td>
        <td>{{ $obra->Autor }}</td>
        <td><small>{{ $obra->Fecha }}<br />{{ $obra->Medidas }}<br />{{ $obra->Tecnica }}</small></td>
        <td><small>{{ $obra->Planta }}<br />{{ $obra->Ubicacion }}</small></td>
        <td>
          <a href="{{ route('obras.edit',$obra->id) }}" class="btn btn-outline-primary btn-sm" title="Editar">
            <span class="oi oi-pencil"></span>
          </a>
          
          @if ($obra->esPublica)
          <form class="d-inline" method="post" action="{{ route('obra.ocultar', $obra->id) }}">
            {!! csrf_field() !!}
            <button type="submit" class="btn btn-outline-primary btn-sm d-inline" title="Dejar de publicar ficha en la web">
              <span class="oi oi-circle-x"></span>
            </button>
          </form>
          @else
          <form class="d-inline" method="post" action="{{ route('obra.publicar', $obra->id) }}">
            {!! csrf_field() !!}
            <button type="submit" class="btn btn-outline-primary btn-sm d-inline" title="Publicar ficha en la web">
              <span class="oi oi-circle-check"></span>
            </button>
          </form>
          @endif
          
          <a href="{{ route('obra.etiqueta',$obra->id) }}" class="btn btn-outline-primary btn-sm" title="Generar etiqueta">
            <span class="oi oi-tag"></span>
          </a>
          
          {{-- La eliminación de obra, tiene que ser confirmada --> abrimos una ventana modal --}}
          <button type="button" class="btn btn-outline-primary btn-sm d-inline" data-toggle="modal" data-target="#Confirmacion{{ $obra->id }}" title="Eliminar">
            <span class="oi oi-delete"></span>
          </button>
          
          <div class="modal fade" id="Confirmacion{{ $obra->id }}" tabindex="-1" role="dialog" aria-labelledby="ConfirmacionTitulo" aria-hidden="true">
            <div class="modal-dialog" role="document">
              <div class="modal-content">
                <div class="modal-header">
                  <h5 class="modal-title" id="ConfirmacionTitulo">Confirmar eliminación de obra</h5>
                  <button type="button" class="close" data-dismiss="modal" aria-label="Cerrar">
                    <span aria-hidden="true">&times;</span>
                  </button>
                </div>
                <div class="modal-body">
                  ¿Estás seguro de que deseas borrar la obra?
                </div>
                <div class="modal-footer">
                  <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancelar eliminación</button>
                  <form class="d-inline" method="post" action="{{ route('obras.destroy', $obra->id) }}">
                    {!! csrf_field() !!}
                    {!! method_field('DELETE') !!}
                    <button type="submit" class="btn btn-primary d-inline" title="Eliminar">
                      Borrar obra
                    </button>
                  </form>
                </div>
              </div>
            </div>
          </div>
          
          
        </td>
      </tr>
      @endforeach
    </tbody>
  </table>
  
  {{-- Mostramos al usuario el botón de crear nueva obra, mientras no haya publicado el límite de su plan de usuario --}}
  @if ( auth()->user()->obras_publicadas() < auth()->user()->obras_plan() )
  <a class="btn btn-primary btn-md" href="{{ route('obras.create') }}">
    <span class="oi oi-plus"></span> Dar de alta nueva obra
  </a>
  @else
  <button class="btn btn-primary btn-md" disabled="disabled"><span class="oi oi-plus"></span> Dar de alta nueva obra</button>
  <small>Has publicado el máximo de obras de tu plan de usuario.</small>
  @endif
  {{-- Mostramos al usuario el botón de generar etiquetas, si tiene obras públicas --}}
  @if ( auth()->user()->obras_publicadas() > 0 )
  <a class="btn btn-primary btn-md" href="{{ route('mis-etiquetas', auth()->user()->id) }}" title="Genera todas las etiquetas de tus obras públicas">
    <span class="oi oi-tags"></span> Generar etiquetas
  </a>
  @endif
  
  @if ($obras->count() == 0)
  @component('components.static_info_sin_obras')
  @endcomponent
  @endif
</div>
@endsection