@extends('layouts/layout')

@section('contenido')
  <div class="container mt-4">
    <div class="row justify-content-center">
      <div class="col-md-8">
        <h1 class="mt-3 mb-5">Contacta con nosotros</h1>

        @if (session()->has('info'))
          @component('components.info_box', ['tipo'=> session('tipo')])
            {{ session('info') }}
          @endcomponent
        @endif
      </div>
  </div>

   
  {{-- Si hay errores de la llamada anterior, los listamos --}}
  @if ($errors->any())
  <div class="row">
    <div class="col-md-8">
      <ul class="list-group">
        @foreach ($errors->all as $error)
        <li class="list-group-item list-group-item-danger">
          {{ $error }}
        </li>
      </div>
    </div>
    @endforeach
  </ul>
  @endif
  
  {{-- Formulario de contacto --}}
  <form method="post" action="{{ route('contacta') }}">
    
    {{-- Seguridad: campo CSRF, para evitar ataques CSS --}}
    {!! csrf_field() !!}
    
    <div class="row justify-content-center">
      <div class="col-md-8">
        
        <div class="row">
          <div class="col">
            <fieldset class="form-group">
              <label for="name">Nombre / Organización <small class="text-primary ml-1">* Obligatorio</small></label>
              <input type="text" class="form-control" name="name" id="name" value="{{ (Auth::check()) ? auth()->user()->name : '' }}" placeholder="Nombre / Organización" required>
              {!! $errors->first('name','<p class=text-danger>:message</p>') !!}
            </fieldset>
          </div>
          <div class="col">
            <fieldset class="form-group">
              <label for="email">Email <small class="text-primary ml-1">* Obligatorio</small></label>
              <input type="email" class="form-control" name="email" id="email" value="{{ (Auth::check()) ? auth()->user()->email : '' }}" placeholder="Email" required>
              {!! $errors->first('email','<p class=text-danger>:message</p>') !!}
            </fieldset>
          </div>
        </div>
        
        <fieldset class="form-group">
          <label for="subject">Asunto <small class="text-primary ml-1">* Obligatorio</small></label>
          <input type="text" class="form-control" name="subject" id="subject" value="" placeholder="Escriba aquí el motivo de su consulta" required>
          {!! $errors->first('subject','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="mensaje">Mensaje <small class="text-primary ml-1">* Obligatorio</small></label>
          <textarea name="Mensaje" id="Mensaje" class="form-control" rows="10" placeholder="Escriba aquí su mensaje" required></textarea>
          {!! $errors->first('mensaje','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <button type="submit" class="btn btn-primary btn-lg mt-5">Enviar mensaje</button>
      </div>
    
    </form>
    
  </div>
  @endsection
  