{{-- Vista edición de cuenta de usuario. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout')

@section('contenido')
<div class="container mt-4">
  <div class="row">
    <div class="col">
      <h1>Editar usuario</h1>
      <h4 class="mb-5 text-muted">{{ $usuario->email }}</h4>
    </div>
  </div>
  
  
  
  @if (session()->has('info'))
  @component('components.info_box', session('tipo'))
  {{ session('info') }}
  @endcomponent
  @endif
  
  @if ($errors->any())
  <div class="row">
    <div class="col">
      <ul class="list-group">
        @foreach ($errors->all as $error)
        <li class="list-group-item list-group-item-danger">
          {{ $error }}
        </li>
      </div>
    </div>
    @endforeach
  </ul>
  @endif
  
  <form method="post" action="{{ route('usuarios.update',$usuario->id) }}">
    
    {{-- Simulamos método PUT (la petición http es tipo POST) --}}
    {!! method_field('PUT') !!}
    {!! csrf_field() !!}
    
    <div class="row">
      <div class="col">
        
        <fieldset class="form-group">
          <label for="name">Nombre / Organización</label>
          <input type="text" class="form-control" name="name" id="name" value="{{ $usuario->name }}" placeholder="Nombre / Organización">
          {!! $errors->first('name','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="email">Email</label>
          <input type="text" class="form-control" name="email" id="email" value="{{ $usuario->email }}" placeholder="Email">
          {!! $errors->first('email','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        {{-- Si el usuario autenticado es administrador, podrá modificar el rol del usuario que se está editando --}}
        @if (auth()->user()->esAdministrador())
        <fieldset class="form-group">
          <label for="rol_id">Rol</label>
          <select class="form-control" name="rol_id" id="rol_id">
            @foreach ($roles as $id => $nombre )
            <option value="{{$id}}" {{ $usuario->rol->id === $id ? 'selected' : '' }} >{{$nombre}}</option>
            @endforeach
          </select>
          {!! $errors->first('rol_id','<p class=text-danger>:message</p>') !!}
        </fieldset>
        @endif
        
        <button type="submit" class="btn btn-primary btn-lg mt-5">Editar usuario</button>
      </div>
      
      <div class="col">
        <fieldset class="form-group">
          <label for="password">Contraseña</label>
          <input type="password" class="form-control" name="password"  id="password" placeholder="Contraseña">
          {!! $errors->first('password','<p class=text-danger>:message</p>') !!}
        </fieldset>
        
        <fieldset class="form-group">
          <label for="password_confirmation">Repetir contraseña</label>
          <input type="password" class="form-control" name="password_confirmation"  id="password_confirmation"  placeholder="Repetir contraseña">
        </fieldset>
        <small class="text-muted">Deja los campos vacíos para no cambiar la contraeña.</small>
      </div>
      
      
      <div class="col">
        
      </div>
    </div>
    
  </form>
  
</div>
@endsection
