{{-- Vista cuenta de usuario. Extiende la plantilla principal layouts/layout --}}
@extends('layouts/layout') @section('contenido')
<div class="container mt-4">
  <div class="row mb-4">
    <div class="col">
      <h1>Mi cuenta de usuario</h1>
    </div>
  </div>
  
  <div class="row">
    <div class="col-12 col-md-6 col-lg-4 mb-4">
      
      {{-- Datos de la cuenta de usuario --}}
      <div class="card">
        <img class="card-img-top" src="{{ $usuario->rol->avatar }}" alt="Imagen de la cuenta de usuario">
        
        <div class="card-body">
          <h5 class="card-title">{{ $usuario->name }}</h5>
          <h6 class="card-subtitle mb-2 text-muted">{{ $usuario->email }}</h6>
          <p class="card-text">{{ $usuario->rol->nombre }}</p>
        </div>

        <div class="card-body">
            <h5 class="card-title text-info">Información de tu plan</h5>
            <small>{{ $usuario->obras_publicadas() }} obras publicadas / {{ $usuario->obras_plan() }} disponibles</small>
            @php
            $porcentajePlan = ($usuario->obras_publicadas() / $usuario->obras_plan() ) * 100;
            @endphp
            <div class="progress" style="height:30px;">
              <div class="progress-bar bg-info" role="progressbar"
              style="width: {{ $porcentajePlan }}%;"
              aria-valuenow="12" aria-valuemin="0" aria-valuemax="{{ $usuario->obras_plan() }}">
              </div>
            </div>
            <p class="card-text">Colecciones disponibles: <span class="text-info">{{ $usuario->colecciones_disponibles() }}</span></p>
            <p class="card-text">Las colecciones pueden estar publicadas hasta <span class="text-info">{{ $usuario->dias_plan() }} días</span>.</span></p>
            <p class="card-text">Precio: <span class="text-info">{{ $usuario->rol->coste_mensual }} &euro;/mes</span></p>
        </div>
        
        <div class="card-body">
          {{-- Si el usuario autenticado tiene permiso de edición de la cuenta de usuario, mostramos la opción --}}
          @can('edit',$usuario)
            <a class="btn btn-primary btn-block mb-3" href="{{ route('usuarios.edit', $usuario->id ) }}">Editar cuenta de usuario</a> 
          @endcan
          {{-- Si el usuario autenticado tiene permiso de eliminación de la cuenta de usuario, mostramos la opción --}}
          @can('destroy',$usuario)
          <button type="button" class="btn btn-secondary btn-block btn-sm" data-toggle="modal" data-target="#Confirmacion{{ $usuario->id }}" title="Eliminar">
            Eliminar cuenta de usuario
          </button>
        
          <div class="modal fade" id="Confirmacion{{ $usuario->id }}" tabindex="-1" role="dialog" aria-labelledby="ConfirmacionTitulo" aria-hidden="true">
            <div class="modal-dialog" role="document">
              <div class="modal-content">
                <div class="modal-header">
                  <h5 class="modal-title" id="ConfirmacionTitulo">Confirmar eliminación</h5>
                  <button type="button" class="close" data-dismiss="modal" aria-label="Cerrar">
                    <span aria-hidden="true">&times;</span>
                  </button>
                </div>
                <div class="modal-body">
                  <p><strong>Atención</strong>: esta acción es irreversible.</p>
                  <p>Al eliminar la cuenta de usuario, se eliminarán todas sus colecciones y obras publicadas.</p>
                  <p><strong>¿Estás seguro de que deseas borrar tu cuenta de usuario?</strong></p>
                </div>
                <div class="modal-footer">
                  <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancelar eliminación</button>
                  <form class="d-inline" method="post" action="{{ route('usuarios.destroy', $usuario->id) }}">
                    {!! csrf_field() !!}
                    {!! method_field('DELETE') !!}
                    <button type="submit" class="btn btn-primary d-inline" title="Eliminar">
                      Eliminar cuenta de usuario
                    </button>
                  </form>
                </div>
              </div>
            </div>
          </div>
           @endcan

        </div>
        
        @if ($usuario->rol->clave === 'esencial')
          <div class="card-footer">
              ¿Necesitas ampliar tu plan de usuario? <a href="{{ route('contacta') }}">Contacta con nosotros</a>.
          </div>
        @endif
    </div>
  </div>
  
  <div class="col-12 col-md-6 col-lg-8">
    <div class="row">
      <div class="col">
        
        {{-- Mostramos las obras publicadas por el usuario --}}
        <h3>Mis obras</h3>
        @if ($obras->count() === 0)
          @component('components.static_info_sin_obras')
          @endcomponent
        @else
        
        {{-- obras de la colección --}}
        <div class="py-5">
          <div class="container">
            <div class="row justify-content-center">
              
              @foreach ($obras as $obra)
              <div class="col-sm-6 col-md-4 col-lg-3 text-center">
                <div class="card mb-4 box-shadow">
                  <img class="card-img-top" src="{{ ($obra->Thumb != null) ? $obra->Thumb : env('ENLAZART_THUMBNAIL') }}" alt="{{ ($obra->Titulo.', '.$obra->Autor) }}">
                  <div class="card-body">
                    <a role="button" href="{{ route('obras.show',$obra->id) }}" class="btn btn-sm btn-outline-secondary">Ver  &raquo;</a>
                    {{-- Si el usuario autenticado puede editar la obra, mostramos enlace de dicha opción --}}
                    @if (Auth::user()->can('edit', $obra))
                      <a role="button" href="{{ route('obras.edit',$obra->id) }}" class="btn btn-sm btn-outline-secondary">Editar  &raquo;</a>
                    @endif
                  </div>
                </div>
              </div>
              @endforeach
              
            </div>
          </div>
        </div>
        
        
        @endif
      </div>
    </div>
    
  </div>
</div>
</div>

</div>



</div>
@endsection

@push('scripts')
@endpush